@@ -1,5 +1,5 @@
 /* -*- c -*- 
-   $Id: cdxa2mpeg.c,v 1.7 2004/02/07 03:00:39 rocky Exp $
+   $Id: cdxa2mpeg.c,v 1.9 2004/10/25 01:44:51 rocky Exp $
 
    Copyright (C) 2001, 2004 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -24,18 +24,22 @@
 # include "config.h"
 #endif
 
+#if defined ( WIN32 )
+#define ftruncate chsize
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
 #include <cdio/sector.h>
+#include <cdio/bytesex.h>
 
 #include <popt.h>
 
 /* Private includes */
 #include "vcd_assert.h"
-#include "bytesex.h"
 #include "util.h"
 #include "vcd.h"
 
