@@ -1,8 +1,8 @@
 /*
-    $Id: vcd-info.c,v 1.4 2004/02/07 03:00:39 rocky Exp $
+    $Id: vcd-info.c,v 1.15 2004/12/01 13:04:59 rocky Exp $
 
-    Copyright (C) 2001,2002 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2002,2003,2004 Rocky Bernstein <rocky@panix.com>
+    Copyright (C) 2001, 2002 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2002, 2003, 2004 Rocky Bernstein <rocky@panix.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 #endif
 
 #include <cdio/cdio.h>
-#include <cdio/logging.h>
+#include <cdio/bytesex.h>
 #include <cdio/iso9660.h>
 
 /* Eventually move above libvcd includes but having vcdinfo including. */
@@ -51,10 +51,9 @@
 
 /* Private headers */
 #include "bitvec.h"
-#include "bytesex.h"
 #include "pbc.h"
 
-static const char _rcsid[] = "$Id: vcd-info.c,v 1.4 2004/02/07 03:00:39 rocky Exp $";
+static const char _rcsid[] = "$Id: vcd-info.c,v 1.15 2004/12/01 13:04:59 rocky Exp $";
 
 static const char DELIM[] = \
 "----------------------------------------" \
@@ -207,14 +206,14 @@ _has_vcd2_ext_pbc (const vcdinfo_obj_t *obj)
     return PBC_VCD2_NOPE;
 
   img = vcdinfo_get_cd_image(obj);
-  statbuf = iso9660_fs_stat (img, "EXT/LOT_X.VCD;1", true);
+  statbuf = iso9660_fs_stat (img, "EXT/LOT_X.VCD;1");
   if (NULL == statbuf)
     return PBC_VCD2_NO_LOT_X;
   if (statbuf->size != ISO_BLOCKSIZE * LOT_VCD_SIZE) {
     ret_status = PBC_VCD2_BAD_LOT_SIZE;
   } else {
     free(statbuf);
-    statbuf = iso9660_fs_stat (img, "EXT/PSD_X.VCD;1", true);
+    statbuf = iso9660_fs_stat (img, "EXT/PSD_X.VCD;1");
     if (NULL != statbuf) {
       ret_status = PBC_VCD2_EXT;
     } else {
@@ -230,7 +229,7 @@ _has_vcd2_ext_pbc (const vcdinfo_obj_t *obj)
 static void
 dump_lot (const vcdinfo_obj_t *obj, bool ext)
 {
-  const LotVcd *lot = ext ? vcdinfo_get_lot_x(obj) : vcdinfo_get_lot(obj);
+  const LotVcd_t *lot = ext ? vcdinfo_get_lot_x(obj) : vcdinfo_get_lot(obj);
   
   unsigned n, tmp;
   const uint16_t max_lid = vcdinfo_get_num_LIDs(obj);
@@ -266,12 +265,12 @@ dump_lot (const vcdinfo_obj_t *obj, bool ext)
 static void
 dump_psd (const vcdinfo_obj_t *obj, bool ext)
 {
-  VcdListNode *node;
+  CdioListNode *node;
   unsigned n = 0;
   unsigned int mult = vcdinfo_get_offset_mult(obj);
   const uint8_t *psd = ext 
     ? vcdinfo_get_psd_x(obj) : vcdinfo_get_psd(obj);
-  VcdList *offset_list = ext 
+  CdioList *offset_list = ext 
     ? vcdinfo_get_offset_x_list(obj) : vcdinfo_get_offset_list(obj);
 
   fprintf (stdout, 
@@ -280,9 +279,9 @@ dump_psd (const vcdinfo_obj_t *obj, bool ext)
            ? "SVCD/PSD.SVD\n"
            : (ext ? "EXT/PSD_X.VCD\n": "VCD/PSD.VCD\n"));
 
-  _VCD_LIST_FOREACH (node, offset_list)
+  _CDIO_LIST_FOREACH (node, offset_list)
     {
-      vcdinfo_offset_t *ofs = _vcd_list_node_data (node);
+      vcdinfo_offset_t *ofs = _cdio_list_node_data (node);
       unsigned _rofs = ofs->offset * mult;
 
       uint8_t type;
@@ -293,7 +292,7 @@ dump_psd (const vcdinfo_obj_t *obj, bool ext)
         {
         case PSD_TYPE_PLAY_LIST:
           {
-            const PsdPlayListDescriptor *pld = (const void *) (psd + _rofs);
+            const PsdPlayListDescriptor_t *pld = (const void *) (psd + _rofs);
             
             int i;
             uint16_t lid = vcdinf_pld_get_lid(pld);
@@ -317,7 +316,7 @@ dump_psd (const vcdinfo_obj_t *obj, bool ext)
                      vcdinf_get_autowait_time(pld));
 
             for (i = 0; i < pld->noi; i++) {
-              fprintf (stdout, "  play-item[%d]: %s\n", i, 
+              fprintf (stdout, "  play-item[%d]: %s\n", i,
                        vcdinfo_pin2str(vcdinf_pld_get_play_item(pld,i)));
             }
             fprintf (stdout, "\n");
@@ -340,7 +339,7 @@ dump_psd (const vcdinfo_obj_t *obj, bool ext)
         case PSD_TYPE_EXT_SELECTION_LIST:
         case PSD_TYPE_SELECTION_LIST:
           {
-            const PsdSelectionListDescriptor *d =
+            const PsdSelectionListDescriptor_t *d =
               (const void *) (psd + _rofs);
             int i;
             const unsigned int lid=vcdinf_psd_get_lid(d);
@@ -416,7 +415,7 @@ dump_psd (const vcdinfo_obj_t *obj, bool ext)
 static void
 dump_info (vcdinfo_obj_t *obj)
 {
-  const InfoVcd *info = vcdinfo_get_infoVcd(obj);
+  const InfoVcd_t *info = vcdinfo_get_infoVcd(obj);
   segnum_t num_segments = vcdinfo_get_num_segments(obj);
   int n;
 
@@ -507,10 +506,12 @@ dump_info (vcdinfo_obj_t *obj)
     fprintf (stdout, " psd size: %u\n", 
              (unsigned int) uint32_from_be (info->psd_size));
 
-  if (gl.show.info.seg)
-    fprintf (stdout, " first segment addr: %2.2x:%2.2x:%2.2x\n",
-             info->first_seg_addr.m, info->first_seg_addr.s, info->first_seg_addr.f);
-  
+  if (gl.show.info.seg) {
+    char *psz_msf = cdio_msf_to_str(&info->first_seg_addr);
+    fprintf (stdout, " first segment addr: %s\n", psz_msf);
+    free(psz_msf);
+  }
+    
   if (gl.show.info.ofm)
     fprintf (stdout, " offset multiplier: 0x%2.2x\n", 
              vcdinfo_get_offset_mult(obj));
@@ -527,12 +528,15 @@ dump_info (vcdinfo_obj_t *obj)
       {
         const lsn_t  lsn = vcdinfo_get_seg_lsn(obj, n);
         msf_t  msf;
+        char *psz_msf;
 
         cdio_lsn_to_msf(lsn, &msf);
+        psz_msf = cdio_msf_to_str(&msf);
         fprintf (stdout, " SEGMENT[%4.4d]: track# 0, LSN %6u "
-                 "(MSF %2.2x:%2.2x:%2.2x), %2u sectors\n",
-                 n, (unsigned int) lsn, msf.m, msf.s, msf.f, 
+                 "(MSF %s), %2u sectors\n",
+                 n, (unsigned int) lsn, psz_msf, 
                  (unsigned int) vcdinfo_get_seg_sector_count(obj, n));
+        free(psz_msf);
 
         fprintf (stdout, "   audio: %s, video: %s, continuation %s%s %s\n",
                  vcdinfo_audio_type2str(obj,
@@ -540,7 +544,7 @@ dump_info (vcdinfo_obj_t *obj)
                  vcdinfo_video_type2str(obj, n),
                  _vcd_bool_str (info->spi_contents[n].item_cont),
                  (vcdinfo_get_VCD_type(obj) == VCD_TYPE_VCD2) 
-                   ? "" : ", OGT substream:",
+                   ? "" : ",\n   SVCD subtitle (OGT) substream:",
                  (vcdinfo_get_VCD_type(obj) == VCD_TYPE_VCD2) 
                    ? "" : vcdinfo_ogt2str(obj, n));
       }
@@ -556,7 +560,7 @@ dump_info (vcdinfo_obj_t *obj)
 static void
 dump_entries (vcdinfo_obj_t *obj)
 {
-  const EntriesVcd *entries = vcdinfo_get_entriesVcd(obj);
+  const EntriesVcd_t *entries = vcdinfo_get_entriesVcd(obj);
   int num_entries, n;
 
   num_entries = vcdinfo_get_num_entries(obj);
@@ -590,13 +594,16 @@ dump_entries (vcdinfo_obj_t *obj)
       {
         const lsn_t  lsn = vcdinfo_get_entry_lsn(obj, n);
         msf_t  msf;
+        char *psz_msf;
 
         cdio_lsn_to_msf(lsn, &msf);
+        psz_msf = cdio_msf_to_str(&msf);
         fprintf (stdout, " ENTRY[%2.2d]: track# %2d (SEQUENCE[%d]), LSN %6u "
-                 "(MSF %2.2x:%2.2x:%2.2x)\n",
+                 "(MSF %s)\n",
                  n, vcdinfo_get_track(obj, n),
-                 vcdinfo_get_track(obj, n) - 1,               
-                 (unsigned int) lsn, msf.m, msf.s, msf.f);
+                 vcdinfo_get_track(obj, n) - 1,
+                 (unsigned int) lsn, psz_msf);
+        free(psz_msf);
       }
 }
 
@@ -643,30 +650,32 @@ dump_tracks_svd (vcdinfo_obj_t *obj)
           "0 & 1 available",
           "all available"
         };
+      char *psz_msf = cdio_msf_to_str(&(tracks->playing_time[j]));
 
-      fprintf (stdout, " track[%.2d]: %2.2x:%2.2x:%2.2x,"
-               " audio: %s, video: %s, OGT stream: %s\n",
-               j,
-               tracks->playing_time[j].m,
-               tracks->playing_time[j].s,
-               tracks->playing_time[j].f,
+      fprintf (stdout, 
+               " track[%.2d]: %s,"
+               " audio: %s, video: %s,\n"
+               "            SVCD subtitle (OGT) stream: %s\n",
+               j, psz_msf,
                vcdinfo_audio_type2str(obj, 
                                       vcdinfo_get_track_audio_type(obj, j+1)),
                video_types[tracks2->contents[j].video],
                ogt_str[tracks2->contents[j].ogt]);
+      free(psz_msf);
     }
 
   fprintf (stdout, "\nCVD interpretation (probably)\n");
   for (j = 0;j < tracks->tracks; j++)
     {
-      fprintf (stdout, "(track[%.2d]: %2.2x:%2.2x:%2.2x (cumulated),"
+
+      char *psz_msf = cdio_msf_to_str(&(tracks_v30->track[j].cum_playing_time));
+      fprintf (stdout, "(track[%.2d]: %s (cumulated),"
                " audio: %.2x, ogt: %.2x)\n",
-               j,
-               tracks_v30->track[j].cum_playing_time.m,
-               tracks_v30->track[j].cum_playing_time.s,
-               tracks_v30->track[j].cum_playing_time.f,
+               j, psz_msf,
                tracks_v30->track[j].audio_info,
                tracks_v30->track[j].ogt_info);
+      free(psz_msf);
+      
     }
 }
 
@@ -690,26 +699,27 @@ dump_tracks (const CdIo *cdio)
   /* Read and possibly print track information. */
   for (i = first_track_num; i <= CDIO_CDROM_LEADOUT_TRACK; i++) {
     msf_t msf;
+    char *psz_msf;
     
     if (!cdio_get_track_msf(cdio, i, &msf)) {
       vcd_error("Error getting information for track %i.\n", i);
       continue;
     }
     
+    psz_msf = cdio_msf_to_str(&msf);
     if (i == CDIO_CDROM_LEADOUT_TRACK) {
-      printf("%3d: %2.2x:%2.2x:%2.2x  %06u  leadout\n",
-             (int) i, 
-             msf.m, msf.s, msf.f, 
+      printf("%3d: %s  %06u  leadout\n",
+             (int) i, psz_msf,
              (unsigned int) cdio_msf_to_lsn(&msf));
       break;
       } else {
-      printf("%3d: %2.2x:%2.2x:%2.2x  %06u  %s\n",
-             (int) i, 
-             msf.m, msf.s, msf.f, 
+      printf("%3d: %s  %06u  %s\n",
+             (int) i, psz_msf,
              (unsigned int) cdio_msf_to_lsn(&msf),
              track_format2str[cdio_get_track_format(cdio, i)]);
       
     }
+    free(psz_msf);
     /* skip to leadout? */
     if (i == num_tracks) i = CDIO_CDROM_LEADOUT_TRACK-1;
   }
@@ -740,14 +750,18 @@ dump_scandata_dat (vcdinfo_obj_t *obj)
         {
           const msf_t *msf = &_sd_v2->points[n];
           const uint32_t lsn = cdio_msf_to_lsn(msf);
+          char *psz_msf;
 
           if (!gl.debug_level >= 1
               && n > PRINTED_POINTS
               && n < scandata_count - PRINTED_POINTS)
             continue;
 
-          fprintf (stdout, "  scanpoint[%.4d]: LSN %lu (msf %2.2x:%2.2x:%2.2x)\n",
-                   n, (long unsigned int) lsn, msf->m, msf->s, msf->f);
+          psz_msf = cdio_msf_to_str(msf);
+          fprintf (stdout, "  scanpoint[%.4d]: LSN %lu (msf %s)\n",
+                   n, (long unsigned int) lsn, psz_msf);
+
+          free(psz_msf);
 
           if (!gl.debug_level >= 1
               && n == PRINTED_POINTS
@@ -778,9 +792,10 @@ dump_scandata_dat (vcdinfo_obj_t *obj)
       for (n = 0; n < track_count; n++)
         {
           const msf_t *msf = &_sd1->cum_playtimes[n];
+          char *psz_msf = cdio_msf_to_str(msf);
 
-          fprintf (stdout, "  cumulative_playingtime[%d]: %2.2x:%2.2x:%2.2x\n",
-                   n, msf->m, msf->s, msf->f);
+          fprintf (stdout, "  cumulative_playingtime[%d]: %s\n", n, psz_msf);
+          free(psz_msf);
         }
  
       for (n = 0; n < spi_count; n++)
@@ -809,6 +824,7 @@ dump_scandata_dat (vcdinfo_obj_t *obj)
         {
           const msf_t *msf = &_sd4->scandata_table[n];
           const uint32_t lsn = cdio_msf_to_lsn(msf);
+          char *psz_msf = cdio_msf_to_str(msf);
 
           if (!gl.debug_level >= 1
               && n > PRINTED_POINTS
@@ -816,9 +832,10 @@ dump_scandata_dat (vcdinfo_obj_t *obj)
             continue;
 
           fprintf (stdout, 
-                   "  scanpoint[%.4d] (ofs:%5d): LSN %lu (MSF %2.2x:%2.2x:%2.2x)\n",
+                   "  scanpoint[%.4d] (ofs:%5d): LSN %lu (MSF %s)\n",
                    n, scandata_ofs0 + (n * 3), (unsigned long int) lsn, 
-                   msf->m, msf->s, msf->f);
+                   psz_msf);
+          free(psz_msf);
 
           if (!gl.debug_level >= 1
               && n == PRINTED_POINTS
@@ -849,12 +866,14 @@ dump_search_dat (vcdinfo_obj_t *obj)
       unsigned hh, mm, ss, ss2;
       const msf_t *msf = &(searchdat->points[m]);
       const uint32_t lsn = cdio_msf_to_lsn(msf);
+      char *psz_msf;
 
       if (!gl.debug_level >= 1 
           && m > PRINTED_POINTS 
           && m < (scan_points - PRINTED_POINTS))
         continue;
       
+      psz_msf = cdio_msf_to_str(msf);
       ss2 = m * searchdat->time_interval;
 
       hh = ss2 / (2 * 60 * 60);
@@ -863,8 +882,9 @@ dump_search_dat (vcdinfo_obj_t *obj)
       ss2 = (ss2 % 2) * 5;
 
       fprintf (stdout, " scanpoint[%.4d]: (real time: %.2d:%.2d:%.2d.%.1d) "
-               " sector: LSN %lu (MSF %.2x:%.2x:%.2x)\n", m, hh, mm, ss, ss2,
-               (unsigned long int) lsn, msf->m, msf->s, msf->f);
+               " sector: LSN %lu (MSF %s)\n", m, hh, mm, ss, ss2,
+               (unsigned long int) lsn, psz_msf);
+      free(psz_msf);
       
       if (!gl.debug_level >= 1
           && m == PRINTED_POINTS && scan_points > (PRINTED_POINTS * 2))
@@ -876,9 +896,9 @@ dump_search_dat (vcdinfo_obj_t *obj)
 static void
 _dump_fs_recurse (const vcdinfo_obj_t *obj, const char pathname[])
 {
-  VcdList *entlist;
-  VcdList *dirlist =  _vcd_list_new ();
-  VcdListNode *entnode;
+  CdioList *entlist;
+  CdioList *dirlist =  _cdio_list_new ();
+  CdioListNode *entnode;
   CdIo *cdio = vcdinfo_get_cd_image(obj);
 
   entlist = iso9660_fs_readdir (cdio, pathname, true);
@@ -889,9 +909,9 @@ _dump_fs_recurse (const vcdinfo_obj_t *obj, const char pathname[])
 
   /* just iterate */
   
-  _VCD_LIST_FOREACH (entnode, entlist)
+  _CDIO_LIST_FOREACH (entnode, entlist)
     {
-      iso9660_stat_t *statbuf = _vcd_list_node_data (entnode);
+      iso9660_stat_t *statbuf = _cdio_list_node_data (entnode);
       char *_name = statbuf->filename;
       char _fullname[4096] = { 0, };
 
@@ -902,7 +922,7 @@ _dump_fs_recurse (const vcdinfo_obj_t *obj, const char pathname[])
       if (statbuf->type == _STAT_DIR
           && strcmp (_name, ".") 
           && strcmp (_name, ".."))
-        _vcd_list_append (dirlist, strdup (_fullname));
+        _cdio_list_append (dirlist, strdup (_fullname));
 
       fprintf (stdout, 
                "  %c %s %d %d [fn %.2d] [LSN %6lu] ",
@@ -924,20 +944,20 @@ _dump_fs_recurse (const vcdinfo_obj_t *obj, const char pathname[])
 
     }
 
-  _vcd_list_free (entlist, true);
+  _cdio_list_free (entlist, true);
 
   fprintf (stdout, "\n");
 
   /* now recurse */
 
-  _VCD_LIST_FOREACH (entnode, dirlist)
+  _CDIO_LIST_FOREACH (entnode, dirlist)
     {
-      char *_fullname = _vcd_list_node_data (entnode);
+      char *_fullname = _cdio_list_node_data (entnode);
 
       _dump_fs_recurse (obj, _fullname);
     }
 
-  _vcd_list_free (dirlist, true);
+  _cdio_list_free (dirlist, true);
 }
 
 static void
@@ -1096,7 +1116,7 @@ dump_all (vcdinfo_obj_t *obj)
 }
 
 static void
-dump (char image_fname[])
+dump (char *image_fname[])
 {
   unsigned size, psd_size;
   vcdinfo_obj_t *obj;
@@ -1113,15 +1133,16 @@ dump (char image_fname[])
                "%s\n\n", _rcsid);
     }
 
-  open_rc = vcdinfo_open(&obj, &image_fname, gl.source_type, gl.access_mode);
+  open_rc = vcdinfo_open(&obj, image_fname, gl.source_type, gl.access_mode);
 
   if (NULL == obj) {
-    if (image_fname == NULL) {
+    if (*image_fname == NULL) {
       fprintf (stdout, "Couldn't automatically find a Video CD.\n");
     } else {
       fprintf (stdout, "Error opening requested Video CD object %s\n",
-               image_fname);
+               *image_fname);
       fprintf (stdout, "Perhaps this is not a Video CD.n");
+      free(*image_fname);
     }
     exit (EXIT_FAILURE);
   }
@@ -1129,6 +1150,7 @@ dump (char image_fname[])
   img = vcdinfo_get_cd_image(obj);
   if (open_rc==VCDINFO_OPEN_ERROR || img == NULL) {
     vcd_error ("Error determining place to read from");
+    free(*image_fname);
     exit (EXIT_FAILURE);
   }
 
@@ -1136,12 +1158,11 @@ dump (char image_fname[])
 
   if (gl.show.source) 
     {
-      if (NULL == image_fname) {
-        image_fname = vcdinfo_get_default_device(obj);
-        fprintf (stdout, "Source: default image file `%s'\n", image_fname);
-        free(image_fname);
+      if (NULL == *image_fname) {
+        *image_fname = vcdinfo_get_default_device(obj);
+        fprintf (stdout, "Source: default image file `%s'\n", *image_fname);
       } else {
-        fprintf (stdout, "Source: image file `%s'\n", image_fname);
+        fprintf (stdout, "Source: image file `%s'\n", *image_fname);
       }
       fprintf (stdout, "Image size: %d sectors\n", size);
     }
@@ -1184,8 +1205,7 @@ dump (char image_fname[])
                                  ((vcdinfo_get_VCD_type(obj) == VCD_TYPE_SVCD 
                              || vcdinfo_get_VCD_type(obj) == VCD_TYPE_HQVCD)
                                   ? "/SVCD/PSD.SVD;1" 
-                                  : "/VCD/PSD.VCD;1"),
-                                 true);
+                                  : "/VCD/PSD.VCD;1"));
       if (NULL == statbuf)
         vcd_warn ("no PSD file entry found in ISO9660 fs");
       else {
@@ -1227,6 +1247,7 @@ enum {
   OP_SOURCE_UNDEF       = DRIVER_UNKNOWN,
   OP_SOURCE_BINCUE      = DRIVER_BINCUE,
   OP_SOURCE_NRG         = DRIVER_NRG,
+  OP_SOURCE_CDRDAO      = DRIVER_CDRDAO,
   OP_SOURCE_DEVICE      = DRIVER_DEVICE,
   OP_SOURCE_SECTOR_2336,
 
@@ -1332,13 +1353,16 @@ main (int argc, const char *argv[])
     {"cue-file", 'c', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
      OP_SOURCE_BINCUE, "set \"cue\" CD-ROM disk image file as source", "FILE"},
 
+    {"nrg-file", 'N', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+     OP_SOURCE_NRG, "set Nero CD-ROM disk image file as source", "FILE"},
+
+    {"toc-file", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+     OP_SOURCE_CDRDAO, "set \"toc\" CD-ROM disk image file as source", "FILE"},
+
     {"input", 'i', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
      OP_SOURCE_UNDEF,
      "set source and determine if \"bin\" image or device", "FILE"},
 
-    {"nrg-file", 'N', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
-     OP_SOURCE_NRG, "set Nero CD-ROM disk image file as source", "FILE"},
-
     {"no-ext-psd", '\0', POPT_ARG_NONE, &gl.no_ext_psd_flag, 0,
      "ignore information in /EXT/PSD_X.VCD"},
 
@@ -1498,7 +1522,7 @@ main (int argc, const char *argv[])
         gl.show.all = false;
         break;
       case OP_VERSION:
-        fprintf (stdout, vcd_version_string (true), "vcdinfo");
+        fprintf (stdout, vcd_version_string (true), "vcd-info");
         fflush (stdout);
         poptFreeContext(optCon);
         exit (EXIT_SUCCESS);
@@ -1510,6 +1534,7 @@ main (int argc, const char *argv[])
 
       case OP_SOURCE_UNDEF:
       case OP_SOURCE_BINCUE: 
+      case OP_SOURCE_CDRDAO: 
       case OP_SOURCE_NRG: 
       case OP_SOURCE_DEVICE: 
       case OP_SOURCE_SECTOR_2336:
@@ -1535,6 +1560,7 @@ main (int argc, const char *argv[])
             okay = OP_SOURCE_DEVICE != opt;
             break;
           case OP_SOURCE_NRG: 
+          case OP_SOURCE_CDRDAO: 
           case OP_SOURCE_DEVICE:
             /* This case is implied, but we'll make it explicit anyway. */
             okay = false;
@@ -1595,10 +1621,12 @@ main (int argc, const char *argv[])
     memset(&gl.show.no, true, sizeof(gl.show.no));
   
   gl_default_vcd_log_handler  = vcd_log_set_handler (_vcd_log_handler);
-  gl_default_cdio_log_handler = cdio_log_set_handler (_vcd_log_handler);
+  gl_default_cdio_log_handler = 
+    cdio_log_set_handler ( (cdio_log_handler_t) _vcd_log_handler);
 
-  dump (source_name);
+  dump (&source_name);
 
+  free(source_name);
   poptFreeContext(optCon);
   return EXIT_SUCCESS;
 }
