@@ -1,5 +1,5 @@
 /*
-    $Id: vcd_xml_common.c,v 1.10 2003/11/10 11:57:48 rocky Exp $
+    $Id: vcd_xml_common.c,v 1.11 2004/12/02 00:33:24 rocky Exp $
 
     Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -33,7 +33,7 @@
 
 #include "vcd_xml_common.h"
 
-static const char _rcsid[] = "$Id: vcd_xml_common.c,v 1.10 2003/11/10 11:57:48 rocky Exp $";
+static const char _rcsid[] = "$Id: vcd_xml_common.c,v 1.11 2004/12/02 00:33:24 rocky Exp $";
 
 bool vcd_xml_gui_mode = false;
 
@@ -254,7 +254,7 @@ _convert (const char in[], const char encoding[], bool from)
       return strdup(in);
   }
 
-  if (ret || (temp - size + 1))
+  if (ret < 0 || (temp - size + 1))
     {
       free (out);
       vcd_error ("charset conversion failed");
