@@ -1,5 +1,5 @@
 /*
-    $Id: vcd_read.h,v 1.2 2003/11/10 11:57:52 rocky Exp $
+    $Id: vcd_read.h,v 1.3 2004/03/28 07:38:06 rocky Exp $
 
     Copyright (C) 2003 Rocky Bernstein <rocky@gnu.org>
 
@@ -29,8 +29,8 @@
 #include <libvcd/files_private.h>
 
 bool read_pvd(CdIo *cdio, iso9660_pvd_t *pvd);
-bool read_entries(CdIo *cdio, EntriesVcd *entries);
-bool read_info(CdIo *cdio, InfoVcd *info, vcd_type_t *vcd_type);
+bool read_entries(CdIo *cdio, EntriesVcd_t *entries);
+bool read_info(CdIo *cdio, InfoVcd_t *info, vcd_type_t *vcd_type);
 
 
 
